ptycho
======
.. automodule:: tike.ptycho
   :inherited-members:
   :members:
   :show-inheritance:
   :undoc-members:

.. automodule:: tike.ptycho.ptycho
   :inherited-members:
   :members:
   :show-inheritance:
   :undoc-members:

   .. autosummary::
      :nosignatures:

      reconstruct
      reconstruct_multigrid
      Reconstruction
      simulate

.. toctree::
   :maxdepth: 3
   :hidden:

   ptycho.exitwave
   ptycho.fresnel
   ptycho.io
   ptycho.learn
   ptycho.object
   ptycho.position
   ptycho.probe
   ptycho.solvers
